ConfigOverrideSetStructuredConfigRequest

Struct ConfigOverrideSetStructuredConfigRequest 

pub struct ConfigOverrideSetStructuredConfigRequest {
    pub moniker: String,
    pub fields: Vec<ConfigOverride>,
}

Fields

moniker: String

The moniker of the component that should use the structured config override. This moniker is relative to the realm that uses this protocol.

fields: Vec<ConfigOverride>